@@ -15,7 +15,7 @@
  *
  */
 
-class htmlform 
+class htmlform
 {
 	/**
 	 * internal tmp-variable to store form
@@ -39,7 +39,7 @@ class htmlform
 			{
 				/*
 				 * here be section title & image
-				 */
+				*/
 				$title = $section['title'];
 				$image = $section['image'];
 
@@ -47,7 +47,7 @@ class htmlform
 				{
 					continue;
 				}
-	
+
 				if (!isset($section['nobuttons']) || $section['nobuttons'] == false) {
 					eval("self::\$_form .= \"" . getTemplate("misc/form/table_section", "1") . "\";");
 				} else {
@@ -65,7 +65,7 @@ class htmlform
 					if ($nexto === false || (isset($fielddata['next_to']) && $nexto['field'] != $fielddata['next_to'])) {
 						$label = $fielddata['label'];
 						$desc = (isset($fielddata['desc']) ? $fielddata['desc'] : '');
-						$style = (isset($fielddata['style']) ? ' style="'.$fielddata['style'].'"' : '');
+						$style = (isset($fielddata['style']) ? ' class="'.$fielddata['style'].'"' : '');
 						$mandatory = self::_getMandatoryFlag($fielddata);
 						$data_field = self::_parseDataField($fieldname, $fielddata);
 						//$data_field = str_replace("\n", "", $data_field);
@@ -83,9 +83,9 @@ class htmlform
 						$data_field = str_replace("\t", "", $data_field);
 						$data_field = $fielddata['next_to_prefix'].$data_field;
 						self::$_form = str_replace(
-							'{NEXTTOFIELD_'.$fielddata['next_to'].'}',
-							$data_field,
-							self::$_form
+								'{NEXTTOFIELD_'.$fielddata['next_to'].'}',
+								$data_field,
+								self::$_form
 						);
 						$nexto = false;
 					}
@@ -123,6 +123,8 @@ class htmlform
 				return self::_textArea($fieldname, $data); break;
 			case 'checkbox':
 				return self::_checkbox($fieldname, $data); break;
+			case 'file':
+				return self::_file($fieldname, $data); break;
 		}
 	}
 
@@ -130,11 +132,11 @@ class htmlform
 	{
 		if(isset($data['mandatory']))
 		{
-			return '&nbsp;<span style="color:#ff0000;">*</span>';
+			return '&nbsp;<span class="red">*</span>';
 		}
 		elseif(isset($data['mandatory_ex']))
 		{
-			return '&nbsp;<span style="color:#ff0000;">**</span>';
+			return '&nbsp;<span class="red">**</span>';
 		}
 		return '';
 	}
@@ -150,8 +152,8 @@ class htmlform
 			$extras .= ' size="'.$data['size'].'"';
 		}
 		if(isset($data['autocomplete'])) {
-                        $extras .= ' autocomplete="'.$data['autocomplete'].'"';
-                }
+			$extras .= ' autocomplete="'.$data['autocomplete'].'"';
+		}
 
 		// add support to save reloaded forms
 		if (isset($data['value'])) {
@@ -161,7 +163,7 @@ class htmlform
 		} else {
 			$value = '';
 		}
-		
+
 		$ulfield = ($unlimited == true ? '&nbsp;'.$data['ul_field'] : '');
 		if(isset($data['display']) && $data['display'] != '')
 		{
@@ -182,7 +184,7 @@ class htmlform
 		if(isset($data['rows'])) {
 			$extras .= ' rows="'.$data['rows'].'"';
 		}
-		
+
 		// add support to save reloaded forms
 		if (isset($data['value'])) {
 			$value = $data['value'];
@@ -201,7 +203,7 @@ class htmlform
 	{
 		return $data['yesno_var'];
 	}
-	
+
 	private static function _labelField($data = array())
 	{
 		return $data['value'];
@@ -217,76 +219,101 @@ class htmlform
 		} else {
 			$select_var = '';
 		}
-		
-		return '<select 
-			id="'.$fieldname.'" 
-			name="'.$fieldname.'" 
-			'.(isset($data['class']) ? ' class="'.$data['class'] .'" ' : '').'
-			>'
-			.$select_var.
-			'</select>';
+
+		return '<select
+				id="'.$fieldname.'"
+						name="'.$fieldname.'"
+								'.(isset($data['class']) ? ' class="'.$data['class'] .'" ' : '').'
+										>'
+										.$select_var.
+										'</select>';
 	}
-	
+
 	/**
 	 * Function to generate checkboxes.
-	 * 
+	 *
 	 * <code>
 	 * $data = array(
-     *                       'label' => $lng['customer']['email_imap'],
-     *                       'type' => 'checkbox',
-     *                       'values' => array(
-     *                                         array(  'label' => 'active',
-     *                                                 'value' => '1'
-     *                                               )
-     *                                           ),
-     *                       'value' => array('1'),
-     *                       'mandatory' => true
-     *          )
+	 *                       'label' => $lng['customer']['email_imap'],
+	 *                       'type' => 'checkbox',
+	 *                       'values' => array(
+	 *                                         array(  'label' => 'active',
+	 *                                                 'value' => '1'
+	 *                                               )
+	 *                                           ),
+	 *                       'value' => array('1'),
+	 *                       'mandatory' => true
+	 *          )
 	 * </code>
-	 * 
+	 *
 	 * @param string $fieldname contains the fieldname
 	 * @param array $data contains the data array
 	 */
 	public static function _checkbox($fieldname = '', $data = array()) {
 		// $data['value'] contains checked items
+
+		$checked = array();
 		if (isset($data['value'])) {
 			$checked = $data['value'];
-		} else {
-			$checked = array();
 		}
-		
+
 		if (isset($_SESSION['requestData'])) {
 			if(isset($_SESSION['requestData'][$fieldname])) {
 				$checked = array($_SESSION['requestData'][$fieldname]);
-			} else {
-				$checked = array();
 			}
 		}
-		
+
 		// default value is none, so the checkbox isn't an array
 		$isArray = '';
-		
-		if (count($data['values']) > 1) {
+
+		if (count($data['values']) > 1 || (isset($data['is_array']) && $data['is_array'] == 1)) {
 			$isArray = '[]';
 		}
-		
+
 		// will contain the output
 		$output = "";
 		foreach($data['values'] as $val) {
 			$key = $val['label'];
 			// is this box checked?
 			$isChecked = '';
-			foreach($checked as $tmp) {
-				if ($tmp == $val['value']) {
-					$isChecked = ' checked="checked" ';
-					break;
+			if (is_array($checked) && count($checked) > 0) {
+				foreach($checked as $tmp) {
+					if ($tmp == $val['value']) {
+						$isChecked = ' checked="checked" ';
+						break;
+					}
 				}
 			}
-			
 			$output .= '<label><input type="checkbox" name="'.$fieldname.$isArray.'" value="'.$val['value'].'" '.$isChecked.'/>'.$key.'</label>';
 		}
-		
+
 		return $output;
 	}
-	
+
+	private static function _file($fieldname = '', $data = array())
+	{
+		$return = '';
+		$extras = '';
+		if(isset($data['maxlength'])) {
+			$extras .= ' maxlength="'.$data['maxlength'].'"';
+		}
+
+		// add support to save reloaded forms
+		if (isset($data['value'])) {
+			$value = $data['value'];
+		} elseif (isset($_SESSION['requestData'][$fieldname])) {
+			$value = $_SESSION['requestData'][$fieldname];
+		} else {
+			$value = '';
+		}
+
+		if(isset($data['display']) && $data['display'] != '')
+		{
+			$ulfield = '<strong>'.$data['display'].'</strong>';
+		}
+
+		eval("\$return = \"" . getTemplate("misc/form/input_file", "1") . "\";");
+		return $return;
+	}
+
 }
