@@ -47,10 +47,12 @@ return array(
 					'new_customer_password' => array(
 						'label' => $lng['login']['password'],
 						'type' => 'password',
+						'autocomplete' => 'off'
 					),
 					'new_customer_password_suggestion' => array(
 						'label' => $lng['customer']['generated_pwd'],
 						'type' => 'text',
+						'visible' => (Settings::Get('panel.password_regex') == ''),
 						'value' => generatePassword(),
 					),
 					'sendpassword' => array(
@@ -120,6 +122,22 @@ return array(
 					'customernumber' => array(
 						'label' => $lng['customer']['customernumber'],
 						'type' => 'text'
+					),
+					'custom_notes' => array(
+						'style' => 'align-top',
+						'label' => $lng['usersettings']['custom_notes']['title'],
+						'desc' => $lng['usersettings']['custom_notes']['description'],
+						'type' => 'textarea',
+						'cols' => 60,
+						'rows' => 12
+					),
+					'custom_notes_show' => array(
+						'label' => $lng['usersettings']['custom_notes']['show'],
+						'type' => 'checkbox',
+						'values' => array(
+							array ('label' => $lng['panel']['yes'], 'value' => '1')
+						),
+						'value' => array()
 					)
 				)
 			),
@@ -180,18 +198,10 @@ return array(
 						'type' => 'textul',
 						'value' => 0,
 						'maxlength' => 9,
-						'visible' => ($settings['system']['mail_quota_enabled'] == '1' ? true : false),
+						'visible' => (Settings::Get('system.mail_quota_enabled') == '1' ? true : false),
 						'mandatory' => true,
 						'ul_field' => $email_quota_ul
 					),
-					'email_autoresponder' => array(
-						'label' => $lng['customer']['autoresponder'],
-						'type' => 'textul',
-						'value' => 0,
-						'maxlength' => 9,
-						'visible' => ($settings['autoresponder']['autoresponder_active'] == '1' ? true : false),
-						'ul_field' => $email_autoresponder_ul
-					),
 					'email_imap' => array(
 						'label' => $lng['customer']['email_imap'],
 						'type' => 'checkbox',
@@ -222,7 +232,7 @@ return array(
 						'type' => 'textul',
 						'value' => 0,
 						'maxlength' => 9,
-						'visible' => ($settings['ticket']['enabled'] == '1' ? true : false),
+						'visible' => (Settings::Get('ticket.enabled') == '1' ? true : false),
 						'ul_field' => $tickets_ul
 					),
 					'mysqls' => array(
@@ -247,19 +257,6 @@ return array(
 						'values' => array(
 										array ('label' => $lng['panel']['yes'], 'value' => '1')
 									)
-					),
-					'backup_allowed' => array(
-						'label' => $lng['backup_allowed'].'?',
-						'type' => 'yesno',
-						'yesno_var' => $backup_allowed
-					),
-					'number_of_aps_packages' => array(
-						'label' => $lng['aps']['numberofapspackages'],
-						'type' => 'textul',
-						'value' => 0,
-						'maxlength' => 9,
-						'visible' => ($settings['aps']['aps_active'] == '1' ? true : false),
-						'ul_field' => $number_of_aps_packages_ul
 					)
 				)
 			)
