@@ -286,7 +286,7 @@ $lng['admin']['admin_edit'] = 'Editar administrador';
 $lng['admin']['customers_see_all'] = 'Mostrar todos os clientes';
 $lng['admin']['domains_see_all'] = 'Mostrar todos os domínios';
 $lng['admin']['change_serversettings'] = 'Alterar configuraççes do servidor?';
-$lng['admin']['server'] = 'Servidor';
+$lng['admin']['server'] = 'Sistema';
 $lng['admin']['serversettings'] = 'Configurações';
 $lng['admin']['rebuildconf'] = 'Escrever de novo os configs';
 $lng['admin']['stdsubdomain'] = 'Subdomínio padrão';
@@ -642,9 +642,11 @@ $lng['serversettings']['logger']['types']['description'] = 'Especificar tipos de
 $lng['serversettings']['logger']['logfile'] = 'Caminho do Arquivo de Log incluindo nome de arquivo';
 $lng['error']['logerror'] = 'Log-Erro: %s';
 $lng['serversettings']['logger']['logcron'] = 'Logar tarefas do cron';
+$lng['serversettings']['logger']['logcronoption']['never'] = 'Nunca';
+$lng['serversettings']['logger']['logcronoption']['once'] = 'Uma vez';
+$lng['serversettings']['logger']['logcronoption']['always'] = 'Sempre';
 $lng['question']['logger_reallytruncate'] = 'Você realmente deseja dividir a tabela "%s"?';
-$lng['admin']['loggersystem'] = 'Systema-Logging';
-$lng['menue']['logger']['logger'] = 'Systema-Logging';
+$lng['admin']['loggersystem'] = 'Sistema-Log';
 $lng['logger']['date'] = 'Data';
 $lng['logger']['type'] = 'Tipo';
 $lng['logger']['action'] = 'Ação';
