@@ -275,7 +275,7 @@ $lng['admin']['admin_edit'] = 'Ändra admin';
 $lng['admin']['customers_see_all'] = 'Kan se alla kunder?';
 $lng['admin']['domains_see_all'] = 'Kan se alla domäner?';
 $lng['admin']['change_serversettings'] = 'Kan ändra serverinställningar?';
-$lng['admin']['server'] = 'Server';
+$lng['admin']['server'] = 'Systemet';
 $lng['admin']['serversettings'] = 'Inställningar';
 $lng['admin']['rebuildconf'] = 'Uppdatera konfig filer';
 $lng['admin']['stdsubdomain'] = 'Standard subdomän';
